@@ -44,7 +44,7 @@ desktopcouch_database_create_document_from_json (CouchdbDatabase *database, gpoi
 
 	if (json_object_has_member (json_object, "record_type")) {
 		if (g_strcmp0 (json_object_get_string_member (json_object, "record_type"),
-			       DESKTOPCOUCH_RECORD_TYPE_CONTACT))
+			       DESKTOPCOUCH_RECORD_TYPE_CONTACT) == 0)
 			document = desktopcouch_document_contact_new ();
 		else
 			document = desktopcouch_document_new ();
@@ -136,7 +136,8 @@ desktopcouch_session_new (void)
 					   "org.desktopcouch.CouchDB");
 
 	error = NULL;
-	success = dbus_g_proxy_call (proxy, "getPort", &error, G_TYPE_INVALID,
+	success = dbus_g_proxy_call (proxy, "getPort", &error,
+				     G_TYPE_INVALID,
 				     G_TYPE_INT, &port, G_TYPE_INVALID);
 
 	/* Free memory */
